class TcSamMacro(object):
    Resources = "Resources"
    Type = "Type"
    Properties = "Properties"
    CodeUri = "CodeUri"
    Desc = "Description"
    Envi = "Environment"
    Vari = "Variables"
    Handler = "Handler"
    MemSize = "MemorySize"
    Runtime = "Runtime"
    Timeout = "Timeout"
    Events = "Events"
    Globals = "Globals"
    Function = "Function"
    VpcConfig = "VpcConfig"
    VpcId = "VpcId"
    SubnetId = "SubnetId"
    LocalZipFile = "LocalZipFile"
    CosBucketName = "CosBucketName"
    CosObjectName = "CosObjectName"
    Role = "Role"

    TrApiGw = "APIGW"
    TrCMQ = "CMQ"
    TrCOS = "COS"
    TrTimer = "Timer"
    TrCKafka = "Ckafka"




class TriggerMacro(object):
    CronExp = "CronExpression"
    HttpMethod = "HttpMethod"
    IntegratedResp = "IntegratedResponse"
    StageName = "StageName"
    Filter = "Filter"
    Prefix = "Prefix"
    Suffix = "Suffix"
    Enable = "Enable"
    Name = "Name"
    Bucket = "Bucket"
    Topic = "Topic"
    MaxMsgNum = "MaxMsgNum"
    Offset = "Offset"
    ServiceId = "ServiceId"
    Message = "Message"
